/* ******************************************************************************************** */
/* *                                                                     		              * */
/* *                           X.25 System Wide Definitions                                   * */
/* *                           ----------------------------                                   * */
/* *                                                                     		              * */
/* *                                  X25_System.h                                            * */
/* *                                                                     		              * */
/* *..........................................................................................* */
/* *                                                                     		              * */
/* *     Definitions for Apple's X.25 Product that are "System Wide" in their scope.          * */
/* *     of Interface routines.             		                                          * */
/* *                                                                     		              * */
/* *                                                                     		              * */
/* *------------------------------------------------------------------------------------------* */
/* *                                                                     		              * */
/* *                   Copyright  1988-1990 Apple Computer, Inc.              		          * */
/* *                               All Rights Reserved                        		          * */
/* *                           Apple Computer Confidential                     		          * */
/* *                                                                     		              * */
/* *------------------------------------------------------------------------------------------* */
/* *                                                                     		              * */
/* *     Revision History:                                               		              * */
/* *                                                                     		              * */
/* *     Date       Individual          Changes                                               * */
/* *     .........  ................... ..................................................    * */
/* *                                                                     		              * */
/* *     17 Jul 89  Group			    Original Version                 		              * */
/* *                                                                     		              * */
/* *                                                                     		              * */
/* ******************************************************************************************** */
    

#ifndef 	_X25_System_Includes_
#define 	_X25_System_Includes_

#include	<Types.h>



/* ******************************************************************************************** */
/* *                                                                     		              * */
/* *	Definitions for the common message header format                       		          * */
/* *                                                                     		              * */
/* ******************************************************************************************** */


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                         	              + */
/* +	The message format class definition.                                                  + */
/* +                                                                       		              + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

typedef enum {   								
	
	_X25_login_msg		= 1,
	_X25_admin_msg		= 2,
	_X25_server_msg		= 3
	
	} message_class_def;


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                         	              + */
/* +	The originator / destination definitions.                                             + */
/* +                                                                       		              + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

typedef enum {   								
	
	_X25_server			= 1,
	_X25_server_agent	= 2,
	_X25_admin			= 3,
	_X25_client			= 4
	
	} message_endpoint_def;


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* +                                                                         	              + */
/* +	The common first portion of all messages.  This structure is included as the first    + */
/* +    item of all message definitions.  This structure may also be overlayed on any message + */
/* +    to allow a decode by message format class.                                            + */
/* +                                                                         	              + */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

typedef struct _X25_common_header {

	Boolean						message_rejected		: 1;
	message_class_def			message_class			: 7;
	message_endpoint_def		src_endpoint			: 4;
	message_endpoint_def		dest_endpoint			: 4;

	} _X25_common_header;




/* ******************************************************************************************** */
/* *                                                                     		              * */
/* *	End of File                       		                                              * */
/* *                                                                     		              * */
/* ******************************************************************************************** */

#endif 	_X25_System_Includes_

